@@ -12,9 +12,9 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
 from django import http
 from django import shortcuts
+from django.urls import reverse
 from django.utils import html
 from django.utils.translation import ugettext_lazy as _
 
