@@ -12,8 +12,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
 from django import http
+from django.urls import reverse
 from django.utils import html
 from django.utils.translation import ugettext_lazy as _
 
